==> haskell-regex-tdfa-1.2.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-regex-tdfa/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-356f1fd0d011fc4d4ac3ea6a1e65b0ca
key: regex_J3z6tWCVrdJDJFi6mr8nNE
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.Tester
    Text.Regex.TDFA.NewDFA.Uncons Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-J3z6tWCVrdJDJFi6mr8nNE
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-tdfa-1.2.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-regex-tdfa/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-tdfa
version: 1.2.2
id: regex-tdfa-1.2.2-5c2f2dacf3d81105b689ea15cddbfda5
key: regex_BHhH6txOvxoFOdieb8wrx7
license: BSD3
copyright: Copyright (c) 2007, Christopher Kuklewicz
maintainer: Artyom <yom@artyom.me>, Christopher Kuklewicz <TextRegexLazy@personal.mightyreason.com>
stability: Seems to work, but not POSIX yet
homepage: https://github.com/ChrisKuklewicz/regex-tdfa
synopsis: Replaces/Enhances Text.Regex
description:
    A new all Haskell "tagged" DFA regex engine, inspired by libtre
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Data.IntMap.CharMap2 Data.IntMap.EnumMap2 Data.IntSet.EnumSet2
    Text.Regex.TDFA Text.Regex.TDFA.ByteString
    Text.Regex.TDFA.ByteString.Lazy Text.Regex.TDFA.Common
    Text.Regex.TDFA.CorePattern Text.Regex.TDFA.IntArrTrieSet
    Text.Regex.TDFA.NewDFA.Engine Text.Regex.TDFA.NewDFA.Engine_FA
    Text.Regex.TDFA.NewDFA.Engine_NC
    Text.Regex.TDFA.NewDFA.Engine_NC_FA Text.Regex.TDFA.NewDFA.Tester
    Text.Regex.TDFA.NewDFA.Uncons Text.Regex.TDFA.NewDFA.MakeTest
    Text.Regex.TDFA.Pattern Text.Regex.TDFA.ReadRegex
    Text.Regex.TDFA.Sequence Text.Regex.TDFA.String
    Text.Regex.TDFA.TDFA Text.Regex.TDFA.TNFA
hidden-modules: Paths_regex_tdfa
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/regex-tdfa-1.2.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/regex-tdfa-1.2.2
hs-libraries: HSregex-tdfa-1.2.2-BHhH6txOvxoFOdieb8wrx7
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
    regex-base-0.93.2-42cdf19dc92d6af642a96da5984c8c2c
haddock-interfaces: /usr/share/doc/haskell-regex-tdfa/html/regex-tdfa.haddock
haddock-html: /usr/share/doc/haskell-regex-tdfa/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
